==> ejc-equipment-api-3.0.0-20210730.025216-269-sources.jar: com/ejianc/business/equipment/vo/SupplementPurchaseContractDetailVO.java <==
package com.ejianc.business.equipment.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 补充协议采购合同明细
 * 
 * @author generator
 * 
 */
public class SupplementPurchaseContractDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long contractId; // 合同主键
    private java.lang.Long equipmentId; // 设备档案主键
    private java.lang.Long applyId; // 设备申请主键
    private java.lang.Long applyDetailId; // 设备申请子表主键
    private java.lang.Integer source; // 来源类型 1-设备档案，2-申请单
    private java.lang.String code; // 设备编码
    private java.lang.String name; // 设备名称
    private java.lang.String spec; // 规格型号
    private java.lang.String unitName; // 计量单位名称
    private java.util.Date arrivalDate; // 到货日期
    private java.math.BigDecimal price; // 单价
    private java.math.BigDecimal num; // 数量
    private java.math.BigDecimal money; // 金额
    private java.lang.String memo; // 备注
    private java.lang.Long changeId; // 变更主键
    private java.lang.Long changeBid; // 变更子表主键
    private java.lang.String changeType; // 变更类型
    private java.lang.Integer srcSupplementFlag; // 是否来源补充协议(1:是，0：否)
    private java.lang.Long srcSupplementId; // 来源补充协议主表ID
    private java.lang.Long srcSupplementDetailId; // 来源补充协议明细ID
    

    /**
     * 合同主键
     */
    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同主键
     */
    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 设备档案主键
     */
    public java.lang.Long getEquipmentId() {
        return equipmentId;
    }

    /**
     * 设备档案主键
     */
    public void setEquipmentId(java.lang.Long equipmentId) {
        this.equipmentId = equipmentId;
    }
    /**
     * 设备申请主键
     */
    public java.lang.Long getApplyId() {
        return applyId;
    }

    /**
     * 设备申请主键
     */
    public void setApplyId(java.lang.Long applyId) {
        this.applyId = applyId;
    }
    /**
     * 设备申请子表主键
     */
    public java.lang.Long getApplyDetailId() {
        return applyDetailId;
    }

    /**
     * 设备申请子表主键
     */
    public void setApplyDetailId(java.lang.Long applyDetailId) {
        this.applyDetailId = applyDetailId;
    }
    /**
     * 来源类型 1-设备档案，2-申请单
     */
    public java.lang.Integer getSource() {
        return source;
    }

    /**
     * 来源类型 1-设备档案，2-申请单
     */
    public void setSource(java.lang.Integer source) {
        this.source = source;
    }
    /**
     * 设备编码
     */
    public java.lang.String getCode() {
        return code;
    }

    /**
     * 设备编码
     */
    public void setCode(java.lang.String code) {
        this.code = code;
    }
    /**
     * 设备名称
     */
    public java.lang.String getName() {
        return name;
    }

    /**
     * 设备名称
     */
    public void setName(java.lang.String name) {
        this.name = name;
    }
    /**
     * 规格型号
     */
    public java.lang.String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(java.lang.String spec) {
        this.spec = spec;
    }
    /**
     * 计量单位名称
     */
    public java.lang.String getUnitName() {
        return unitName;
    }

    /**
     * 计量单位名称
     */
    public void setUnitName(java.lang.String unitName) {
        this.unitName = unitName;
    }
    /**
     * 到货日期
     */
    public java.util.Date getArrivalDate() {
        return arrivalDate;
    }

    /**
     * 到货日期
     */
    public void setArrivalDate(java.util.Date arrivalDate) {
        this.arrivalDate = arrivalDate;
    }
    /**
     * 单价
     */
    public java.math.BigDecimal getPrice() {
        return price;
    }

    /**
     * 单价
     */
    public void setPrice(java.math.BigDecimal price) {
        this.price = price;
    }
    /**
     * 数量
     */
    public java.math.BigDecimal getNum() {
        return num;
    }

    /**
     * 数量
     */
    public void setNum(java.math.BigDecimal num) {
        this.num = num;
    }
    /**
     * 金额
     */
    public java.math.BigDecimal getMoney() {
        return money;
    }

    /**
     * 金额
     */
    public void setMoney(java.math.BigDecimal money) {
        this.money = money;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 变更主键
     */
    public java.lang.Long getChangeId() {
        return changeId;
    }

    /**
     * 变更主键
     */
    public void setChangeId(java.lang.Long changeId) {
        this.changeId = changeId;
    }
    /**
     * 变更子表主键
     */
    public java.lang.Long getChangeBid() {
        return changeBid;
    }

    /**
     * 变更子表主键
     */
    public void setChangeBid(java.lang.Long changeBid) {
        this.changeBid = changeBid;
    }
    /**
     * 变更类型
     */
    public java.lang.String getChangeType() {
        return changeType;
    }

    /**
     * 变更类型
     */
    public void setChangeType(java.lang.String changeType) {
        this.changeType = changeType;
    }
    /**
     * 是否来源补充协议(1:是，0：否)
     */
    public java.lang.Integer getSrcSupplementFlag() {
        return srcSupplementFlag;
    }

    /**
     * 是否来源补充协议(1:是，0：否)
     */
    public void setSrcSupplementFlag(java.lang.Integer srcSupplementFlag) {
        this.srcSupplementFlag = srcSupplementFlag;
    }
    /**
     * 来源补充协议主表ID
     */
    public java.lang.Long getSrcSupplementId() {
        return srcSupplementId;
    }

    /**
     * 来源补充协议主表ID
     */
    public void setSrcSupplementId(java.lang.Long srcSupplementId) {
        this.srcSupplementId = srcSupplementId;
    }
    /**
     * 来源补充协议明细ID
     */
    public java.lang.Long getSrcSupplementDetailId() {
        return srcSupplementDetailId;
    }

    /**
     * 来源补充协议明细ID
     */
    public void setSrcSupplementDetailId(java.lang.Long srcSupplementDetailId) {
        this.srcSupplementDetailId = srcSupplementDetailId;
    }
    
}

==> ejc-equipment-api-3.0.0-20210909.063036-279-sources.jar: com/ejianc/business/equipment/vo/SupplementPurchaseContractDetailVO.java <==
package com.ejianc.business.equipment.vo;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 补充协议采购合同明细
 * 
 * @author generator
 * 
 */
public class SupplementPurchaseContractDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long contractId; // 合同主键
    private java.lang.Long equipmentId; // 设备档案主键
    private java.lang.Long applyId; // 设备申请主键
    private java.lang.Long applyDetailId; // 设备申请子表主键
    private java.lang.Integer source; // 来源类型 1-设备档案，2-申请单
    private java.lang.String code; // 设备编码
    private java.lang.String name; // 设备名称
    private java.lang.String spec; // 规格型号
    private java.lang.String unitName; // 计量单位名称
    private java.util.Date arrivalDate; // 到货日期
    private java.math.BigDecimal price; // 单价
    private java.math.BigDecimal num; // 数量
    private java.math.BigDecimal money; // 金额
    private java.lang.String memo; // 备注
    private java.lang.Long changeId; // 变更主键
    private java.lang.Long changeBid; // 变更子表主键
    private java.lang.String changeType; // 变更类型
    private java.lang.Integer srcSupplementFlag; // 是否来源补充协议(1:是，0：否)
    private java.lang.Long srcSupplementId; // 来源补充协议主表ID
    private java.lang.Long srcSupplementDetailId; // 来源补充协议明细ID

    /**
     * 单价(含税)
     */
    private BigDecimal taxPrice;

    /**
     * 税率
     */
    private BigDecimal detaiTaxRate;

    /**
     * 金额（含税）
     */
    private BigDecimal taxMoney;

    /**
     * 税额
     */
    private BigDecimal tax;

    public BigDecimal getTaxPrice() {
        return taxPrice;
    }

    public void setTaxPrice(BigDecimal taxPrice) {
        this.taxPrice = taxPrice;
    }

    public BigDecimal getDetaiTaxRate() {
        return detaiTaxRate;
    }

    public void setDetaiTaxRate(BigDecimal detaiTaxRate) {
        this.detaiTaxRate = detaiTaxRate;
    }

    public BigDecimal getTaxMoney() {
        return taxMoney;
    }

    public void setTaxMoney(BigDecimal taxMoney) {
        this.taxMoney = taxMoney;
    }

    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }
    /**
     * 合同主键
     */
    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同主键
     */
    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 设备档案主键
     */
    public java.lang.Long getEquipmentId() {
        return equipmentId;
    }

    /**
     * 设备档案主键
     */
    public void setEquipmentId(java.lang.Long equipmentId) {
        this.equipmentId = equipmentId;
    }
    /**
     * 设备申请主键
     */
    public java.lang.Long getApplyId() {
        return applyId;
    }

    /**
     * 设备申请主键
     */
    public void setApplyId(java.lang.Long applyId) {
        this.applyId = applyId;
    }
    /**
     * 设备申请子表主键
     */
    public java.lang.Long getApplyDetailId() {
        return applyDetailId;
    }

    /**
     * 设备申请子表主键
     */
    public void setApplyDetailId(java.lang.Long applyDetailId) {
        this.applyDetailId = applyDetailId;
    }
    /**
     * 来源类型 1-设备档案，2-申请单
     */
    public java.lang.Integer getSource() {
        return source;
    }

    /**
     * 来源类型 1-设备档案，2-申请单
     */
    public void setSource(java.lang.Integer source) {
        this.source = source;
    }
    /**
     * 设备编码
     */
    public java.lang.String getCode() {
        return code;
    }

    /**
     * 设备编码
     */
    public void setCode(java.lang.String code) {
        this.code = code;
    }
    /**
     * 设备名称
     */
    public java.lang.String getName() {
        return name;
    }

    /**
     * 设备名称
     */
    public void setName(java.lang.String name) {
        this.name = name;
    }
    /**
     * 规格型号
     */
    public java.lang.String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(java.lang.String spec) {
        this.spec = spec;
    }
    /**
     * 计量单位名称
     */
    public java.lang.String getUnitName() {
        return unitName;
    }

    /**
     * 计量单位名称
     */
    public void setUnitName(java.lang.String unitName) {
        this.unitName = unitName;
    }
    /**
     * 到货日期
     */
    public java.util.Date getArrivalDate() {
        return arrivalDate;
    }

    /**
     * 到货日期
     */
    public void setArrivalDate(java.util.Date arrivalDate) {
        this.arrivalDate = arrivalDate;
    }
    /**
     * 单价
     */
    public java.math.BigDecimal getPrice() {
        return price;
    }

    /**
     * 单价
     */
    public void setPrice(java.math.BigDecimal price) {
        this.price = price;
    }
    /**
     * 数量
     */
    public java.math.BigDecimal getNum() {
        return num;
    }

    /**
     * 数量
     */
    public void setNum(java.math.BigDecimal num) {
        this.num = num;
    }
    /**
     * 金额
     */
    public java.math.BigDecimal getMoney() {
        return money;
    }

    /**
     * 金额
     */
    public void setMoney(java.math.BigDecimal money) {
        this.money = money;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 变更主键
     */
    public java.lang.Long getChangeId() {
        return changeId;
    }

    /**
     * 变更主键
     */
    public void setChangeId(java.lang.Long changeId) {
        this.changeId = changeId;
    }
    /**
     * 变更子表主键
     */
    public java.lang.Long getChangeBid() {
        return changeBid;
    }

    /**
     * 变更子表主键
     */
    public void setChangeBid(java.lang.Long changeBid) {
        this.changeBid = changeBid;
    }
    /**
     * 变更类型
     */
    public java.lang.String getChangeType() {
        return changeType;
    }

    /**
     * 变更类型
     */
    public void setChangeType(java.lang.String changeType) {
        this.changeType = changeType;
    }
    /**
     * 是否来源补充协议(1:是，0：否)
     */
    public java.lang.Integer getSrcSupplementFlag() {
        return srcSupplementFlag;
    }

    /**
     * 是否来源补充协议(1:是，0：否)
     */
    public void setSrcSupplementFlag(java.lang.Integer srcSupplementFlag) {
        this.srcSupplementFlag = srcSupplementFlag;
    }
    /**
     * 来源补充协议主表ID
     */
    public java.lang.Long getSrcSupplementId() {
        return srcSupplementId;
    }

    /**
     * 来源补充协议主表ID
     */
    public void setSrcSupplementId(java.lang.Long srcSupplementId) {
        this.srcSupplementId = srcSupplementId;
    }
    /**
     * 来源补充协议明细ID
     */
    public java.lang.Long getSrcSupplementDetailId() {
        return srcSupplementDetailId;
    }

    /**
     * 来源补充协议明细ID
     */
    public void setSrcSupplementDetailId(java.lang.Long srcSupplementDetailId) {
        this.srcSupplementDetailId = srcSupplementDetailId;
    }
    
}
